# VPNCMD

<badges>[![version](https://img.shields.io/pypi/v/vpncmd.svg)](https://pypi.org/project/vpncmd/)
[![license](https://img.shields.io/pypi/l/vpncmd.svg)](https://pypi.org/project/vpncmd/)
[![pyversions](https://img.shields.io/pypi/pyversions/vpncmd.svg)](https://pypi.org/project/vpncmd/)  
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![powered](https://img.shields.io/badge/Powered%20by-UTF8-red.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>API for Softether VPN (vpncmd) with automatic connection to VPNs provided by VPN Gate.</i>

# Hierarchy

```
vpncmd
```

# Example

## python
See `test`.